@@ -8,9 +8,10 @@ import json
 import os
 
 from django.conf import settings
+from django.db.models import get_apps
 from django.test import TransactionTestCase
 
-
+ERROR_TEXT = u'line={0}, file={1}, url={2}, post_params={3}'
 def test_runner(self):
     """smoke test"""
 
@@ -26,33 +27,46 @@ def test_runner(self):
     for f in sorted(os.listdir(self.smoknur_path)):
         if f.endswith('.dbg'):
             with open(os.path.join(self.smoknur_path, f)) as f_dbg:
-                for line in f_dbg:
+                for index, line in enumerate(f_dbg, 1):
                     if not line.startswith('#'):
                         req = json.loads(line)
-                        print req['url'], req['params']
-                        resp = self.client.post(
-                            req['url'],
-                            req['params']
-                        )
-                        self.assertTrue(
-                            resp.status_code in (200, 302))
 
-# нужно так, чтобы не было задвоение имени приложения в пути, src/epk/epk/core
-root_path = settings.PROJECT_ROOT.rsplit('/', 1)[0]
+                        try:
+                            resp = self.client.post(
+                                req['url'],
+                                req['params']
+                            )
+                        except:
+                            print ERROR_TEXT.format(
+                                index,
+                                f,
+                                req['url'],
+                                req['params'])
+                            raise
+
+                        self.assertTrue(
+                            resp.status_code in (200, 302),
+                            ERROR_TEXT.format(
+                                index,
+                                f,
+                                req['url'],
+                                req['params']))
+
+exclude_apps = getattr(settings, 'SMOKNUR_EXCLUDE_APPS', ())
 
 # добавляем в глобал тесткейсы
-for app in settings.PROJECT_APPS:
+for app in get_apps():
 
-    # формируем путь к папкам с тестами по приложениям
-    paths = [root_path]
-    paths.extend(app.split('.'))
-    paths.append('smoknur')
+    if app.__package__ in exclude_apps:
+        continue
 
-    path = os.path.join(*paths)
+    path = os.path.join(
+        os.path.dirname(app.__file__),
+        'smoknur')
 
     if os.path.exists(path):
 
-        test_name = app.replace('.', '_').upper()
+        test_name = app.__package__.replace('.', '_').upper()
         
         attrs = {
             'fixtures': [],
